@@ -140,7 +140,8 @@ class KeyBinding:
     """KeyBinding.  May be a multi-part "Chord" (e.g. 'Ctrl+K Ctrl+C').
 
     This is the primary representation of a fully resolved keybinding. For consistency
-    in the downstream API, it should  be preferred to :class:`SimplyKeyBinding`, even
+    in the downstream API, it should be preferred to
+    [`SimpleKeyBinding`][app_model.types.SimpleKeyBinding], even
     when there is only a single part in the keybinding (i.e. when it is not a chord.)
 
     Chords (two separate keypress actions) are expressed as a string by separating
@@ -164,12 +165,9 @@ class KeyBinding:
         return f"<{self.__class__.__name__} at {hex(id(self))}: {self}>"
 
     def __eq__(self, other: Any) -> bool:
-        if not isinstance(other, KeyBinding):
-            try:
-                other = KeyBinding.validate(other)
-            except Exception:  # pragma: no cover
-                return NotImplemented
-        return bool(self.parts == other.parts)
+        if isinstance(other, KeyBinding):
+            return self.parts == other.parts
+        return NotImplemented
 
     def __len__(self) -> int:
         return len(self.parts)
